@@ -31,7 +31,8 @@ def get_destination_tables_with_schema(queries_config, query_name, schema_name,
 
 
 class DataSource:
-    def __init__(self, dbstream: DBStream, path_to_datasource_folder, schema_prefix=None, config_name='config'):
+    def __init__(self, dbstream: DBStream, path_to_datasource_folder, schema_prefix=None, config_name='config',
+                 layer_type='datasource'):
         """
 
         :param dbstream:
@@ -41,6 +42,7 @@ class DataSource:
         self.path_to_datasource_folder = path_to_datasource_folder
         self.schema_prefix = schema_prefix
         self.config_name = config_name
+        self.layer_type = layer_type
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
@@ -78,7 +80,7 @@ class DataSource:
         folder_path = self._build_folder_path(layer_name)
         config = yaml.load(open(folder_path + ("%s.yaml" % self.config_name)), Loader=yaml.FullLoader)
         queries = config.get("queries")
-        schema_name = config.get("schema_name") if config.get("schema_name") else ("datasource_" + layer_name)
+        schema_name = config.get("schema_name") if config.get("schema_name") else (self.layer_type + "_" + layer_name)
         schema_name = self.schema_prefix + '_' + schema_name if self.schema_prefix else schema_name
         if not queries:
             log_info("No queries set up in config file")
@@ -183,7 +185,6 @@ class DataSource:
         print("ENVIRONMENTS COMPARISON RESULTS")
         print("=============================")
         for table in tables_list:
-            print("Result of %s" % table)
 
             destination_tables_with_schema = get_destination_tables_with_schema(
                 schema_name=schema_name,
@@ -192,6 +193,10 @@ class DataSource:
                 environment=environment
             )
 
+            print("Result of %s" % destination_tables_with_schema[environment])
+
+            test_where_clause = queries_config[table].get("test_where_clause")
+
             # Prod
             prod_data_types = self.dbstream.get_data_type(
                 table_name=destination_tables_with_schema["production"].split(".")[1],
@@ -205,7 +210,8 @@ class DataSource:
                 dbstream=self.dbstream,
                 schema_name=destination_tables_with_schema["production"].split(".")[0],
                 table=destination_tables_with_schema["production"].split(".")[1],
-                data_types=prod_data_types
+                data_types=prod_data_types,
+                test_where_clause=test_where_clause
             )
 
             # Other Environment
@@ -217,7 +223,8 @@ class DataSource:
                 dbstream=self.dbstream,
                 schema_name=destination_tables_with_schema[environment].split(".")[0],
                 table=destination_tables_with_schema[environment].split(".")[1],
-                data_types=env_data_types
+                data_types=env_data_types,
+                test_where_clause=test_where_clause
             )
 
             main_dict = {}
